/*  f2520_regs.h
      
    Header file that defines pic18f2520 registers and bits.
*/

// Special-purpose Registers, Bank 0
 #BYTE BAUDCON      = 0xFB8
 #BYTE EECON1      = 0xFA6
 #BYTE EECON2      = 0xFA7
 #BYTE EEADR      = 0xFA9
 #BYTE EEDATA      = 0xFA8
 #BYTE PORTA        = 0xF80
 #BYTE PORTB       = 0xF81
 #BYTE PORTC      = 0xF82
 #BYTE PORTD        = 0xF83
 #BYTE PORTE        = 0xF84
 #BYTE LATA          = 0xF89
 #BYTE LATB          = 0xF8A
 #BYTE LATC          = 0xF8B
 #BYTE LATD         = 0xF8C
 #BYTE LATE         = 0xF8D
 #BYTE TRISA        = 0xF92
 #BYTE TRISB        = 0xF93
 #BYTE TRISC        = 0xF94
 #BYTE TRISD        = 0xF95
 #BYTE TRISE        = 0xF96
 #BYTE PIR1          = 0xF9E
 #BYTE PIR2          = 0xFA1
 #BYTE TXREG        = 0xFAD
 #BYTE RCREG        = 0xFAE
 #BYTE TMR3L        = 0xFB2
 #BYTE TMR3H        = 0xFB3
 #BYTE ADCON2       = 0xFC0
 #BYTE ADCON1      = 0xFC1
 #BYTE ADCON0      = 0xFC2
 #BYTE ADRESL      = 0xFC3
 #BYTE ADRESH      = 0xFC4
 #BYTE SSPCON2      = 0xFC5
 #BYTE SSPCON1      = 0xFC6
 #BYTE SSPSTAT      = 0xFC7
 #BYTE SSPADD      = 0xFC8
 #BYTE SSPBUF      = 0xFC9
 #BYTE TMR2         = 0xFCC
 #BYTE TMR1L        = 0xFCE
 #BYTE TMR1H        = 0xFCF
 #BYTE TMR0L       = 0xFD6
 #BYTE TMR0H       = 0xFD7
 #BYTE STATUS       = 0xFD8
 #BYTE FSR2L        = 0xFD9
 #BYTE FSR2H       = 0XFDA
 #BYTE INDF2        = 0xFDF
 #BYTE BSR            = 0xFE0
 #BYTE FSR1L        = 0xFE1
 #BYTE FSR1H        = 0xFE2
 #BYTE INDF1        = 0xFE7
 #BYTE WREG         = 0xFE8
 #BYTE FSR0L        = 0xFE9
 #BYTE FSR0H        = 0xFEA
 #BYTE INDF0       = 0xFEF
 #BYTE INTCON3      = 0xFF0
 #BYTE INTCON2      = 0xFF1
 #BYTE INTCON       = 0xFF2
 #BYTE TABLAT       = 0xFF5
 #BYTE T0CON       = 0xFD5
 #BYTE T1CON       = 0xFCD
 #BYTE T2CON       = 0xFCA
 #BYTE T3CON        = 0xFB1
 #BYTE CCP1CON       = 0xFBD
 #BYTE CCPR1H       = 0xFBF
 #BYTE CCPR1L       = 0xFBE
 #BYTE CCPR2H       = 0xFBC
 #BYTE CCPR2L       = 0xFBB
 #BYTE CCP2CON       = 0xFBA
 #BYTE PIE1          = 0xF9D
 #BYTE PIE2          = 0xFA0
 #BYTE PR2           = 0xFCB
 #BYTE TXSTA         = 0xFAC
 #BYTE RCSTA         = 0xFAB
 #BYTE SPBRG         = 0xFAF
 #BYTE SPRBGH      = 0xFB0
 #BYTE INTCON3       = 0xFF0

//******************************************************************
//                       PORT BIT DEFINITIONS
//******************************************************************

//STATUS register bits
 #BIT    CARRY       =     STATUS.0
 #BIT    DC          =     STATUS.1
 #BIT    ZERO        =     STATUS.2
 #BIT    PWR_DOWN    =     STATUS.3
 #BIT    TIME_OUT    =     STATUS.4
 #BIT    RP0         =     STATUS.5
 #BIT    RP1         =     STATUS.6
 #BIT    IRP         =     STATUS.7

//INTCON register bits
 #BIT    RBIF       = INTCON.0
 #BIT    INT0IF       = INTCON.1
 #BIT    TMR0IF       = INTCON.2
 #BIT    RBIE       = INTCON.3
 #BIT    INT0IE       = INTCON.4
 #BIT    TMR0IE       = INTCON.5
 #BIT    PEIE       = INTCON.6
 #BIT    GIE        = INTCON.7

 // PIR1 register bits
 #BIT    TMR1IF     =  PIR1.0
 #BIT    TMR2IF     =  PIR1.1
 #BIT    CCP1IF     =  PIR1.2
 #BIT    SSPIF      =  PIR1.3
 #BIT    TXIF       =  PIR1.4
 #BIT    RCIF       =  PIR1.5
 #BIT    ADIF       =  PIR1.6
 #BIT    PSPIF      =  PIR1.7

// PIR2 register bits
 #BIT    CCP2IF     =  PIR2.0
 #BIT   TMR3IF      =  PIR2.1
 #BIT   HLVDIF      =  PIR2.2
 #BIT   BCLIF       =  PIR2.3
 #BIT   EEIF        =  PIR2.4
 #BIT   CMIF        =  PIR2.6
 #BIT   OSCFIF      =  PIR2.7

// T1CON register bits
 #bit   TMR1ON      =  T1CON.0
 #BIT    TMR1CS     =  T1CON.1
 #BIT    T1SYNC_    =  T1CON.2
 #BIT    T1OSCEN    =  T1CON.3
 #BIT    T1CKPS0    =  T1CON.4
 #BIT    T1CKPS1    =  T1CON.5

 // T2CON register bits
 #BIT    T2CKPS0    =  T2CON.0
 #BIT    T2CKPS1    =  T2CON.1
 #BIT    TMR2ON     =  T2CON.2
 #BIT    TOUTPS0    =  T2CON.3
 #BIT    TOUTPS1    =  T2CON.4
 #BIT    TOUTPS2    =  T2CON.5
 #BIT    TOUTPS3    =  T2CON.6

 // SSPSTAT register bits
 #BIT    BF         = SSPSTAT.0
 #BIT    UA       = SSPSTAT.1
 #BIT    R_W       = SSPSTAT.2
 #BIT    S          = SSPSTAT.3
 #BIT    P          = SSPSTAT.4
 #BIT    D_A       = SSPSTAT.5
 #BIT    CKE       = SSPSTAT.6
 #BIT    SMP       = SSPSTAT.7

 // SSPCON register bits
 #BIT    SSPM0      =  SSPCON1.0
 #BIT    SSPM1      =  SSPCON1.1
 #BIT    SSPM2      =  SSPCON1.2
 #BIT    SSPM3      =  SSPCON1.3
 #BIT    CKP        =  SSPCON1.4
 #BIT    SSPEN      =  SSPCON1.5
 #BIT    SSPOV      =  SSPCON1.6
 #BIT    WCOL       =  SSPCON1.7

// SSPCON2 register bits
#BIT   SEN         =  SSPCON2.0
#BIT   RSEN      =  SSPCON2.1
#BIT   PEN         =  SSPCON2.2
#BIT   RCEN      =  SSPCON2.3
#BIT   ACKEN      =  SSPCON2.4
#BIT   ACKDT      =  SSPCON2.5
#BIT   ACKSTAT      =  SSPCON2.6
#BIT   GCEN      =  SSPCON2.7

 // CCP1CON register bits
 #BIT    CCP1M0     =  CCP1CON.0
 #BIT    CCP1M1     =  CCP1CON.1
 #BIT    CCP1M2     =  CCP1CON.2
 #BIT    CCP1M3     =  CCP1CON.3
 #BIT    CCP1Y      =  CCP1CON.4
 #BIT    CCP1X      =  CCP1CON.5

 // CCP2CON register bits
 #BIT    CCP2M0     =  CCP2CON.0
 #BIT    CCP2M1     =  CCP2CON.1
 #BIT    CCP2M2     =  CCP2CON.2
 #BIT    CCP2M3     =  CCP2CON.3
 #BIT    CCP2Y      =  CCP2CON.4
 #BIT    CCP2X      =  CCP2CON.5

  // ADCON0 register bits
 #BIT    ADON       =  ADCON0.0
 #BIT    GO         =  ADCON0.1
 #BIT    DONE_      =  ADCON0.1
 #BIT    CHS0       =  ADCON0.2
 #BIT    CHS1       =  ADCON0.3
 #BIT    CHS2       =  ADCON0.4
 #BIT    CHS3      =  ADCON0.5
 //#BIT          =  ADCON0.6
 //#BIT          =  ADCON0.7

 // ADCON2 register bits 
 #BIT    ADCS0      =  ADCON2.0
 #BIT    ADCS1      =  ADCON2.1
 #BIT    ADCS2      =  ADCON2.2
 #BIT    ACQT0        =  ADCON2.3
 #BIT    ACQT1     =  ADCON2.4
 #BIT    ACQT2      =  ADCON2.5
 //#BIT             =  ADCON2.6
 #BIT    ADFM      =  ADCON2.7

 // T0CON register bits
 #BIT    T0PS0        =  T0CON.0
 #BIT    T0PS1        =  T0CON.1
 #BIT    T0PS2        =  T0CON.2
 #BIT    PSA        =  T0CON.3
 #BIT    T0SE       =  T0CON.4
 //#BIT    RTE        =  T0CON.4
 #BIT    T0CS       =  T0CON.5
 //#BIT    RTS        =  T0CON.5
 #BIT    T08BIT     =  T0CON.6
 //#BIT    INTEDG     =  T0CON.6
 #BIT    TMR0ON     =  T0CON.7 
 //#BIT    RBPU_      =  T0CON.7

 // TRISA register bits
 #BIT    TRIS_A0    =  TRISA.0
 #BIT    TRIS_A1    =  TRISA.1
 #BIT    TRIS_A2    =  TRISA.2
 #BIT    TRIS_A3    =  TRISA.3
 #BIT    TRIS_A4    =  TRISA.4
 #BIT    TRIS_A5    =  TRISA.5
 #BIT    TRIS_A6    =  TRISA.6
 #BIT    TRIS_A7    =  TRISA.7

 // TRISB register bits
 #BIT    TRIS_B0    =  TRISB.0
 #BIT    TRIS_B1    =  TRISB.1
 #BIT    TRIS_B2    =  TRISB.2
 #BIT    TRIS_B3    =  TRISB.3
 #BIT    TRIS_B4    =  TRISB.4
 #BIT    TRIS_B5    =  TRISB.5
 #BIT    TRIS_B6    =  TRISB.6
 #BIT    TRIS_B7    =  TRISB.7

 // TRISC register bits
 #BIT    TRIS_C0    =  TRISC.0
 #BIT    TRIS_C1    =  TRISC.1
 #BIT    TRIS_C2    =  TRISC.2
 #BIT    TRIS_C3    =  TRISC.3
 #BIT    TRIS_C4    =  TRISC.4
 #BIT    TRIS_C5    =  TRISC.5
 #BIT    TRIS_C6    =  TRISC.6
 #BIT    TRIS_C7    =  TRISC.7

 // TRISD register bits
 #BIT    TRIS_D0    =  TRISD.0
 #BIT    TRIS_D1    =  TRISD.1
 #BIT    TRIS_D2    =  TRISD.2
 #BIT    TRIS_D3    =  TRISD.3
 #BIT    TRIS_D4    =  TRISD.4
 #BIT    TRIS_D5    =  TRISD.5
 #BIT    TRIS_D6    =  TRISD.6
 #BIT    TRIS_D7    =  TRISD.7

 // TRISE register bits
 #BIT    TRIS_E0    =  TRISE.0
 #BIT    TRIS_E1    =  TRISE.1
 #BIT    TRIS_E2    =  TRISE.2
 #BIT    TRIS_E3    =  TRISE.3
 #BIT    TRIS_E4    =  TRISE.4
 #BIT    TRIS_E5    =  TRISE.5
 #BIT    TRIS_E6    =  TRISE.6
 #BIT    TRIS_E7    =  TRISE.7

 // PIE1 register bits
 #BIT    TMR1IE     =  PIE1.0
 #BIT    TMR2IE     =  PIE1.1
 #BIT    CCP1IE     =  PIE1.2
 #BIT    SSPIE      =  PIE1.3
 #BIT    TXIE       =  PIE1.4
 #BIT    RCIE       =  PIE1.5
 #BIT    ADIE       =  PIE1.6
 #BIT    PSPIE      =  PIE1.7

 // PIE2.
 #BIT   OSFIE      =  PIE2.7
 #BIT   C2IE      =  PIE2.6
 #BIT   C1IE      =  PIE2.5
 #BIT   EEIE      =  PIE2.4
 #BIT   BCLIE       =  PIE2.3
 #BIT   HLVDIE      =  PIE2.2
 #BIT   TMR3IE      =  PIE2.1
 #BIT   CCP2IE      =  PIE2.0

 // ADCON1 register bits
 #BIT    PCFG0      =  ADCON1.0
 #BIT    PCFG1      =  ADCON1.1
 #BIT    PCFG2      =  ADCON1.2

 // EECON1
 #BIT   EEPGD      =  EECON1.7
 #BIT   CFGS      =  EECON1.6
 #BIT   WRERR      =  EECON1.3
 #BIT   WREN      =  EECON1.2
 #BIT   WR      =  EECON1.1
 #BIT   RD      =  EECON1.0

 // BAUDCON
 #BIT   ABDOVF      =  BAUDCON.7
 #BIT   RCIDL      =  BAUDCON.6
 #BIT   SCKP      =  BAUDCON.5
 #BIT   BRG16      =  BAUDCON.3
 #BIT   WUE      =  BAUDCON.1
 #BIT   ABDEN      =  BAUDCON.0

 // RCSTA
 #BIT   SPEN      =  RCSTA.7
 #BIT   RX9      =  RCSTA.6
 #BIT   SREN      =  RCSTA.5
 #BIT   CREN      =  RCSTA.4
 #BIT   ADDEN      =  RCSTA.3
 #BIT   FERR      =  RCSTA.2
 #BIT   OERR      =  RCSTA.1
 #BIT   RX9D      =  RCSTA.0

 // TXSTA
 #BIT   CSRC      =  TXSTA.7
 #BIT   TX9      =  TXSTA.6
 #BIT   TXEN      =  TXSTA.5
 #BIT   SYNC      =  TXSTA.4
 #BIT   SENDB      =  TXSTA.3
 #BIT   BRGH      =  TXSTA.2
 #BIT   TRMT      =  TXSTA.1
 #BIT   TX9D      =  TXSTA.0

// Select component to connect for A/D conversion
#BIT   NMUX0      = PORTB.2
#BIT   NMUX1      = PORTB.3

// INTCON3
#BIT   INT1IF    = INTCON3.0
#BIT   INT2IF     = INTCON3.1

// PORTB

#BIT	PINB4	= PORTB.4
#BIT	PINB5	= PORTB.5
#BIT	PINB6	= PORTB.6
#BIT	PINB7	= PORTB.7