#include "18F2520.h"
#include "f2520_regs.h"
#fuses INTRC_IO
//#use delay(clock=1000000)
#use delay(clock = 2000000)

#use fixed_io(b_outputs=PIN_B4,PIN_B5,PIN_B6,PIN_B7) 

#define DECIMAL_POINT_ADDRESS 10

const unsigned char CA_LED[10][8] = {

  {0xFE, 0xFD, 0xFB, 0xF7, 0xEF, 0xDF, 0xFF, 0x7F},		//	0
  	
  {0xFD, 0xFB, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7F},		//	1
  
  {0xFE, 0xFD, 0xBF, 0xEF, 0xF7, 0xFF, 0xFF, 0x7F},		//	2

  {0xFE, 0xFD, 0xBF, 0xFB, 0xF7, 0xFF, 0xFF, 0x7F},		//	3
  
  {0xDF, 0xBF, 0xFD, 0xFB, 0xFF, 0xFF, 0xFF, 0x7F},		//	4
	
  {0xFE, 0xDF, 0xBF, 0xFB, 0xF7, 0xFF, 0xFF, 0x7F},		//	5
  
  {0xFE, 0xDF, 0xEF, 0xF7, 0xFB, 0xBF, 0xFF, 0x7F},		//	6

  {0xFE, 0xFD, 0xFB, 0xFF, 0xFF, 0xFF, 0xFF, 0x7F},		//	7
  
  {0xFE, 0xFD, 0xFB, 0xF7, 0xEF, 0xDF, 0xBF, 0x7F},		//	8
  
  {0xFE, 0xFD, 0xFB, 0xF7, 0xDF, 0xBF, 0xFF, 0x7F},		//	9

};

unsigned int SEGMENT = 0;
unsigned char digits[4];

unsigned int16 blink = 0, blink1 = 0;

unsigned int16 number;
unsigned int j = 0;
unsigned int1 blink_flag = 1;
unsigned int i;

int1 Decimal_point;
int Decimal_point_Value;

unsigned int1 UP = 0;
unsigned int1 ENTER = 0;

void value_with_decimal();
void decimal_point_selection();
void increment_value();

#INT_EXT
void interrupt()
{
   UP = 1;
}

#INT_EXT1
void interrupt_1()
{
   ENTER = 1;
}

#INT_TIMER0
void timer0_isr()
{
	if(TMR0IF == 1)
	{
		blink++;	
		blink1++;	// used for delay in the program
		
		if(blink == 500)
		{
			blink_flag = 0;
		}
		
		if(blink == 1000)
		{
			blink = 0;
			blink_flag = 1;
		}
		
		TMR0IF = 0;
		TMR0IE = 1;	
		TMR0H = 0xFE;   // 1ms for 2Mhz
		TMR0L = 0x0B; 	
	}
}

#INT_TIMER1
void timer1_isr()
{
	if(TMR1IF == 1)
	{
		PORTB = 0;
		PORTA = 0xFF;
		
		switch(SEGMENT)
		{
			case 0: PORTA = CA_LED[digits[j]][0];
					break;

			case 1: PORTA = CA_LED[digits[j]][1];
					break;

			case 2: PORTA = CA_LED[digits[j]][2];
					break;

			case 3: PORTA = CA_LED[digits[j]][3];
					break;

			case 4: PORTA = CA_LED[digits[j]][4];
					break;

			case 5: PORTA = CA_LED[digits[j]][5];
					break;

			case 6: PORTA = CA_LED[digits[j]][6];
					break;	

			case 7: 
					if(decimal_point == 0)
					{			
						PORTA = ((CA_LED[digits[j]][7]) | 0b11111111);  // for no decimal point selection 
						break;	
					}

					else if(decimal_point == 1)				// For decimal point selection
					{
						PORTA = CA_LED[digits[j]][7];
						break;		
					}
		};

		if(SEGMENT++ == 8)
		{
			SEGMENT = 0;
			j++;
		}

		value_with_decimal();

		if(j > 3)
		{
			j = 0;
		}
		
		TMR1IF = 0;
		TMR1IE = 1;
		TMR1H = 0xFF;   // 250us for 2Mhz
		TMR1L = 0x82; 
	}
}

void main()
{
	TRISA = 0b00000000;
	TRISB = 0b00000111;

	PORTA = 0;
	PORTB = 0;

	T0CON = 0b10001000;
	TMR0H = 0xFE;   // 1ms for 2Mhz
	TMR0L = 0x0B; 

	T1CON = 0b10000000;
	TMR1H = 0xFF;   // 250us for 2Mhz
	TMR1L = 0x82;  

	TMR1ON = 1;
	TMR1IF = 0;
	TMR1IE = 1;

	ext_int_edge(H_TO_L);
	enable_interrupts(INT_EXT);
	
	ext_int_edge(H_TO_L);
	enable_interrupts(INT_EXT1);
	
	#priority TIMER1, TIMER0, EXT, EXT1

	enable_interrupts(INT_TIMER0);
	enable_interrupts(INT_TIMER1);
	enable_interrupts(GLOBAL);

	number = 8888;

	DECIMAL_POINT_VALUE = read_eeprom(DECIMAL_POINT_ADDRESS);

	digits[0] = number / 1000;
	digits[1] = (number / 100) % 10;
	digits[2] = (number / 10) % 10;
	digits[3] = number % 10;

	while(1)
	{
	//	increment_value();

		decimal_point_selection();
		DECIMAL_POINT_VALUE = read_eeprom(DECIMAL_POINT_ADDRESS);

	}
}

void decimal_point_selection()
{
	write_eeprom(DECIMAL_POINT_ADDRESS, 3);
}

void value_with_decimal()
{
	if(decimal_point_value == 0)	// No Decimal Point
	{
		if(j == 0)				//	For digit 1
		{
			if(i == 0)			// blink digit 0 during increment. variable i is global. it gets the value from the function "void increment_value()"
			{
				if(blink_flag == 0)	// for blinking action 
				{
					PORTB = 0x80;	
					decimal_point = 0;
				}
			
				if(blink_flag == 1)	
				{
					PORTB = 0x00;
				}	
			}	
			else 				// Not blinking action
			{
				PORTB = 0x80;	
				decimal_point = 0;
			}
		}
		
		if(j == 1)		// for digit 1
		{
			if(i == 1)		// blink digit 1 during increment. 
			{
				if(blink_flag == 0)	// for blinking
				{
					PORTB = 0x40;
					decimal_point = 0;
				}	

				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x40;
				decimal_point = 0;
			}
		}
		
		if(j == 2)		// for digit 2
		{
			if(i == 2)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x20;
					decimal_point = 0;
				}
	
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x20;
				decimal_point = 0;				
			}
		}
		
		if(j == 3)		// for digit 3
		{
			if(i == 3)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x10;
					decimal_point = 0;
				}
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 	
			{
				PORTB = 0x10;
				decimal_point = 0;			
			}
		}
	}
	
	if(decimal_point_value == 1)	// One decimal point
	{	
		if(j == 0)
		{
			if(i == 0)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x80;	
					decimal_point = 0;
				}
			
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}	
			}	
			else 
			{
				PORTB = 0x80;	
				decimal_point = 0;
			}
		}
		
		if(j == 1)
		{
			if(i == 1)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x40;
					decimal_point = 0;
				}	

				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x40;
				decimal_point = 0;
			}
		}
		
		if(j == 2)
		{
			if(i == 2)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x20;
					decimal_point = 1;
				}
	
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x20;
				decimal_point = 1;				
			}
		}
		
		if(j == 3)
		{
			if(i == 3)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x10;
					decimal_point = 0;
				}
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 	
			{
				PORTB = 0x10;
				decimal_point = 0;			
			}
		}
	}

	if(decimal_point_value == 2)	// Two Decimal point
	{	
		if(j == 0)
		{	
			if(i == 0)				// digit 0
			{
				if(blink_flag == 0)		// For blinking the digit. 
				{
					PORTB = 0x80;	
					decimal_point = 0;
				}
			
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}	
			}	
			else 
			{
				PORTB = 0x80;	
				decimal_point = 0;
			}
		}
		
		if(j == 1)
		{
			if(i == 1)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x40;
					decimal_point = 1;
				}	

				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x40;
				decimal_point = 1;
			}
		}
		
		if(j == 2)
		{
			if(i == 2)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x20;
					decimal_point = 0;
				}
	
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x20;
				decimal_point = 0;				
			}
		}
		
		if(j == 3)
		{
			if(i == 3)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x10;
					decimal_point = 0;
				}
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 	
			{
				PORTB = 0x10;
				decimal_point = 0;			
			}
		}
	}

	if(decimal_point_value == 3)	// Three Decimal point
	{	
		if(j == 0)
		{
			if(i == 0)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x80;	
					decimal_point = 1;
				}
			
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}	
			}	
			else 
			{
				PORTB = 0x80;	
				decimal_point = 1;
			}
		}
		
		if(j == 1)
		{
			if(i == 1)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x40;
					decimal_point = 0;
				}	

				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x40;
				decimal_point = 0;
			}
		}
		
		if(j == 2)
		{
			if(i == 2)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x20;
					decimal_point = 0;
				}
	
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 
			{
				PORTB = 0x20;
				decimal_point = 0;				
			}
		}
		
		if(j == 3)
		{
			if(i == 3)
			{
				if(blink_flag == 0)
				{
					PORTB = 0x10;
					decimal_point = 0;
				}
				if(blink_flag == 1)
				{
					PORTB = 0x00;
				}
			}
			else 	
			{
				PORTB = 0x10;
				decimal_point = 0;			
			}
		}
	}
}

void increment_value()
{
	unsigned int temp;

	if(UP == 1)			// if UP button is pressed
	{	
		blink1 = 0;
		while(blink1 == 50);
		UP = 0;
		i++;		// increment the variable
	}
	
	switch(i)
	{
		case 0: 
				if(ENTER == 1)			// if Enter button is pressed	
				{
					ENTER = 0;
					digits[0] = (digits[0]) + 1;		// increment digit 0 value
				}	
				if(digits[0] > 9)
				{
					digits[0] = 0;
				}
				break;

		case 1:
				if(ENTER == 1)	
				{
					ENTER = 0;
					digits[1] = (digits[1]) + 1;		// increment digit 1 value
				}
				if(digits[1] > 9)
				{
					digits[1] = 0;
				}
				break;
		
		case 2:
				if(ENTER == 1)
				{
					ENTER = 0;
					digits[2] = (digits[2]) + 1;	// increment digit 2 value
				}
				if(digits[2] > 9)
				{
					digits[2] = 0;
				}
				break;

		case 3:
				if(ENTER == 1)
				{
					ENTER = 0;
					digits[3] = (digits[3]) + 1;		// increment digit 3 value
				}
				if(digits[3] > 9)
				{
					digits[3] = 0;
				}
				break;
    };	

	if(i > 3)			// if i value greater than 3 
	{
		i = 0;			// reset to 0
	}

	blink1 = 0;
	while(blink1 == 1000);
}